Radiation
---------

.. _radiation:

.. inheritance-diagram:: climlab.radiation.Radiation
   :parts: 1
   :private-bases:

.. automodule:: climlab.radiation.radiation
    :members:
    :private-members:
    :undoc-members:
    :show-inheritance:
